document.addEventListener("DOMContentLoaded", function() {
    let expensesChart = null;
    const rangeLabel = document.getElementById("chartRangeLabel");

    function loadExpenses(range = "monthly", startDate = null, endDate = null) {
        let url = '/admin/expenses_data?range=' + range;
        if (startDate && endDate) {
            url += `&start_date=${startDate}&end_date=${endDate}`;
        }

        fetch(url, {cache: "no-store"})
        .then(response => response.json())
        .then(data => {
            const ctx = document.getElementById('expensesChart').getContext('2d');

            if (expensesChart) {
                expensesChart.destroy();
            }

            expensesChart = new Chart(ctx, {
                type: 'bar',
                data: {
                    labels: data.labels,
                    datasets: [{
                        label: 'Suma wydatków [PLN]',
                        data: data.expenses,
                        backgroundColor: '#0d6efd'
                    }]
                },
                options: {
                    scales: {
                        y: {
                            beginAtZero: true
                        }
                    }
                }
            });

            if (startDate && endDate) {
                rangeLabel.textContent = `Widok: własny zakres (${startDate} → ${endDate})`;
            } else {
                let labelText = "";
                if (range === "monthly") labelText = "Widok: miesięczne";
                else if (range === "quarterly") labelText = "Widok: kwartalne";
                else if (range === "halfyearly") labelText = "Widok: półroczne";
                else if (range === "yearly") labelText = "Widok: roczne";
                rangeLabel.textContent = labelText;
            }

        })
        .catch(error => {
            console.error("Błąd pobierania danych:", error);
        });
    }

    document.getElementById('loadExpensesBtn').addEventListener('click', function() {
        loadExpenses();
    });

    document.querySelectorAll('.range-btn').forEach(btn => {
        btn.addEventListener('click', function() {
            document.querySelectorAll('.range-btn').forEach(b => b.classList.remove('active'));
            this.classList.add('active');
            const range = this.getAttribute('data-range');
            loadExpenses(range);
        });
    });

    document.getElementById('customRangeBtn').addEventListener('click', function() {
        const startDate = document.getElementById('startDate').value;
        const endDate = document.getElementById('endDate').value;
        if (startDate && endDate) {
            document.querySelectorAll('.range-btn').forEach(b => b.classList.remove('active'));
            loadExpenses('custom', startDate, endDate);
        } else {
            alert("Proszę wybrać obie daty!");
        }
    });
});

document.addEventListener("DOMContentLoaded", function() {
    const startDateInput = document.getElementById("startDate");
    const endDateInput = document.getElementById("endDate");

    const today = new Date();
    const threeDaysAgo = new Date(today);
    threeDaysAgo.setDate(today.getDate() - 7);

    const formatDate = (d) => d.toISOString().split('T')[0];

    startDateInput.value = formatDate(threeDaysAgo);
    endDateInput.value = formatDate(today);
});